MapLocale enum
Supported language enum.
This enum is used to specify the language of the text to be translated.
Values
- arabic → const MapLocale
-
const MapLocale("ar") - english → const MapLocale
-
const MapLocale("en") - spanish → const MapLocale
-
const MapLocale("es") - portuguese → const MapLocale
-
const MapLocale("pt") - german → const MapLocale
-
const MapLocale("de") - french → const MapLocale
-
const MapLocale("fr") - italian → const MapLocale
-
const MapLocale("it") - russian → const MapLocale
-
const MapLocale("ru") - chinese → const MapLocale
-
const MapLocale("ch") - korean → const MapLocale
-
const MapLocale("ko") - japanese → const MapLocale
-
const MapLocale("ja") - hindi → const MapLocale
-
const MapLocale("hi") - persian → const MapLocale
-
const MapLocale("fa")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- locale → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited