pinConfig static method
Creates a BitmapDescriptor that can be used to customize
AdvancedMarker's pin.
backgroundColor is the color of the pin's background.
borderColor is the color of the pin's border.
glyph is the pin's glyph to be displayed on the pin.
See PinConfig for more information on the parameters.
WARNING: On iOS, using a PinConfig may result in the marker not showing. For details and updates, see https://issuetracker.google.com/issues/370536110. If this issue has not been fixed in the version of the Google Maps SDK you are using, consider using an asset or bitmap for customization on iOS.
Returns a new PinConfig instance.
Implementation
static BitmapDescriptor pinConfig({
Color? backgroundColor,
Color? borderColor,
AdvancedMarkerGlyph? glyph,
}) {
return PinConfig(
backgroundColor: backgroundColor,
borderColor: borderColor,
glyph: glyph,
);
}